@@ -9,20 +9,46 @@ Released under MIT license.
 """
 import inspect
 
-
-from sqlalchemy import MetaData
-from sqlalchemy.engine import Engine
-from sqlalchemy.orm import _mapper_registry, class_mapper
-from sqlalchemy.orm.session import Session
-from sqlalchemy.orm.scoping import ScopedSession
+try:
+    from sqlalchemy import MetaData
+    from sqlalchemy.engine import Engine
+    from sqlalchemy.orm import _mapper_registry, class_mapper
+    from sqlalchemy.orm.session import Session
+    from sqlalchemy.orm.scoping import ScopedSession
+except ImportError: # pragma: no cover
+    pass
 
 try: #pragma:no cover
     from sqlalchemy.orm.instrumentation import ClassManager
 except ImportError: #pragma:no cover
-    #sa 0.6- support
-    from sqlalchemy.orm.attributes import ClassManager
+    try: # pragma: no cover
+        #sa 0.6- support
+        from sqlalchemy.orm.attributes import ClassManager
+    except ImportError:
+        pass
+
+SAORMProvider = None
+try:
+    from sprox.sa.provider import SAORMProvider
+except ImportError: # pragma: no cover
+    pass
+#MongoKitProvider = None
+#try:
+#    from sprox.mk.provider import MongoKitProvider
+#except ImportError: # pragma: no cover
+#    pass
+MingProvider = None
+MappedClass = None
+try:
+    from sprox.mg.provider import MingProvider
+    try:
+        from ming.odm.declarative import MappedClass
+    except ImportError: #pragma: no cover
+        from ming.orm.declarative import MappedClass
+
+except ImportError:   # pragma: no cover
+    pass
 
-from sprox.saormprovider import SAORMProvider
 from sprox.dummyentity import DummyEntity
 
 class ProviderSelector:
@@ -39,13 +65,29 @@ class ProviderSelector:
     def get_provider(self, entity, **hints):
         raise NotImplementedError
 
+#class _MongoKitSelector(ProviderSelector):
+#    def get_identifier(self, entity, **hints):
+#        return entity.__name__
+
+#    def get_provider(self, entity=None, hint=None, **hints):
+#        #TODO cache
+#        return MongoKitProvider(None)
+
+class _MingSelector(ProviderSelector):
+    #def get_identifier(self, entity, **hints):
+    #    return entity.__name__
+
+    def get_provider(self, entity=None, hint=None, **hints):
+        #TODO cache
+        return MingProvider(entity.__mongometa__.session)
+
+
 class _SAORMSelector(ProviderSelector):
 
     def __init__(self):
         self._providers = {}
 
     def _get_engine(self, hint, hints):
-        metadata = hints.get('metadata', None)
         metadata = hints.get('metadata', None)
         engine   = hints.get('engine', None)
         session  = hints.get('session', None)
@@ -96,7 +138,7 @@ class _SAORMSelector(ProviderSelector):
         The provider's are cached as not to waste computation/memory.
 
         :Usage:
-        
+
         >>> from sprox.providerselector import SAORMSelector
         >>> provider = SAORMSelector.get_provider(User, session=session)
         >>> provider.engine.url.drivername
@@ -120,6 +162,8 @@ class _SAORMSelector(ProviderSelector):
         return self._providers[engine]
 
 SAORMSelector = _SAORMSelector()
+#MongoKitSelector = _MongoKitSelector()
+MingSelector = _MingSelector()
 
 #XXX:
 #StormSelector = _StormSelector()
@@ -135,6 +179,11 @@ class ProviderTypeSelector(object):
             return SAORMSelector
         elif inspect.isclass(entity) and issubclass(entity, DummyEntity):
             return SAORMSelector
+        #elif hasattr(entity, '_use_pylons') or hasattr(entity,'_enable_autoref'):
+            #xxx: find a better marker
+        #    return MongoKitSelector
+        elif inspect.isclass(entity) and MappedClass is not None and issubclass(entity, MappedClass):
+            return MingSelector
         #other helper definitions are going in here
         else:
             raise ProviderTypeSelectorError('Entity %s has no known provider mapping.'%entity)
