@@ -12,8 +12,14 @@ import unittest
 
 from nose.plugins import doctests as nose_doctest
 
-from sprox import configbase, fillerbase, formbase, saormprovider, sprockets, tablebase, metadata, validators, validatorselector, widgets, widgetselector
-from sprox.dojo import formbase as dojo_formbase
+from sprox import configbase, fillerbase, formbase, sprockets, tablebase, metadata, validators, validatorselector, widgets, widgetselector, recordviewbase
+
+try:
+    from sprox.dojo import formbase as dojo_formbase
+except ImportError:
+    dojo_formbase = None
+
+from sprox.sa import provider as saormprovider
 
 import sprox
 
@@ -28,7 +34,7 @@ def setup():
     user = setup_records(session)
     #this may be needed if we end up testing the provider with doctests
     #session.commit()
-    
+
 
 def check_output_xml(want, got, optionsflags):
     return eq_xml(want, got)
@@ -54,7 +60,7 @@ def test_doctests():
     global session, metadata
     import unittest
     import doctest
-    
+
     def setUp(self):
         #this may be needed if we end up testing the provider with doctests
         pass
@@ -70,7 +76,9 @@ def test_doctests():
                 suite.addTest(doctest.DocTestSuite(mod, globs={'session':session, 'User': User, 'Town':Town, 'metadata':metadata}, setUp=setUp, tearDown=tearDown))
             except ValueError:
                 pass
-    suite.addTest(doctest.DocTestSuite(dojo_formbase, globs={'session':session, 'User': User, 'Town':Town, 'metadata':metadata}, setUp=setUp, tearDown=tearDown))
+
+    if dojo_formbase:
+        suite.addTest(doctest.DocTestSuite(dojo_formbase, globs={'session':session, 'User': User, 'Town':Town, 'metadata':metadata}, setUp=setUp, tearDown=tearDown))
 
     runner = unittest.TextTestRunner(verbosity=10)
     runner.run(suite)
